@@ -17,12 +17,13 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: ephy-location-action.c 7695 2007-11-16 15:03:10Z xan $
+ *  $Id$
  */
 
 #include "config.h"
 
 #include "ephy-embed-container.h"
+#include "ephy-history.h"
 #include "ephy-location-action.h"
 #include "ephy-location-entry.h"
 #include "ephy-shell.h"
@@ -31,12 +32,9 @@
 #include "ephy-debug.h"
 
 #include <gdk/gdkkeysyms.h>
-#include <gtk/gtkentry.h>
-#include <gtk/gtkstock.h>
-#include <gtk/gtkimage.h>
-#include <gtk/gtkentrycompletion.h>
-#include <gtk/gtkmain.h>
+#include <gtk/gtk.h>
 
+#include <string.h>
 #define EPHY_LOCATION_ACTION_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), EPHY_TYPE_LOCATION_ACTION, EphyLocationActionPrivate))
 
 struct _EphyLocationActionPrivate
@@ -47,6 +45,7 @@ struct _EphyLocationActionPrivate
 	char *typed_address;
 	EphyNode *smart_bmks;
 	EphyBookmarks *bookmarks;
+	EphyNode *history;
 	GdkPixbuf *icon;
 	char *lock_stock_id;
 	char *lock_tooltip;
@@ -82,36 +81,63 @@ enum
 	LOCK_CLICKED,
 	LAST_SIGNAL
 };
-static guint signals[LAST_SIGNAL] = { 0 };
+static guint signals[LAST_SIGNAL];
 
-static GObjectClass *parent_class = NULL;
+G_DEFINE_TYPE (EphyLocationAction, ephy_location_action, EPHY_TYPE_LINK_ACTION)
 
-GType
-ephy_location_action_get_type (void)
+static gboolean
+match_func (GtkEntryCompletion *completion,
+		const char *key,
+		GtkTreeIter *iter,
+		gpointer data)
 {
-	static GType type = 0;
+	char *item = NULL;
+	char *url = NULL;
+	char *keywords = NULL;
+	char *extra = NULL;
 
-	if (G_UNLIKELY (type == 0))
+	gboolean ret = FALSE;
+	GtkTreeModel *model;
+	GSList *search_terms;
+
+	model = gtk_entry_completion_get_model (completion);
+
+	gtk_tree_model_get (model, iter,
+			    EPHY_COMPLETION_TEXT_COL, &item,
+			    EPHY_COMPLETION_URL_COL, &url,
+			    EPHY_COMPLETION_KEYWORDS_COL, &keywords,
+			    EPHY_COMPLETION_EXTRA_COL, &extra,
+			    -1);
+	
+	if (!key)
+		return FALSE;
+	
+	search_terms = ephy_location_entry_get_search_terms (data);
+
+	if (search_terms)
 	{
-		const GTypeInfo type_info =
-		{
-			sizeof (EphyLocationActionClass),
-			(GBaseInitFunc) NULL,
-			(GBaseFinalizeFunc) NULL,
-			(GClassInitFunc) ephy_location_action_class_init,
-			(GClassFinalizeFunc) NULL,
-			NULL,
-			sizeof (EphyLocationAction),
-			0, /* n_preallocs */
-			(GInstanceInitFunc) ephy_location_action_init,
-		};
+		GSList *iter;
+		GRegex *current = NULL;
 
-		type = g_type_register_static (EPHY_TYPE_LINK_ACTION,
-					       "EphyLocationAction",
-					       &type_info, 0);
+		ret = TRUE;
+		for (iter = search_terms; iter != NULL; iter = iter->next)
+		{
+			current = (GRegex*) iter->data;
+			if ((!g_regex_match (current, item, G_REGEX_MATCH_NOTEMPTY, NULL)) &&
+			    (!g_regex_match (current, url, G_REGEX_MATCH_NOTEMPTY, NULL)) &&
+			    (!g_regex_match (current, keywords, G_REGEX_MATCH_NOTEMPTY, NULL)))
+			{
+				ret = FALSE;
+				break;
+			}
+		}
 	}
 
-	return type;
+	g_free (item);
+	g_free (url);
+	g_free (keywords);
+
+	return ret;
 }
 
 static void
@@ -372,9 +398,14 @@ connect_proxy (GtkAction *action, GtkWidget *proxy)
 						    EPHY_COMPLETION_ACTION_COL,
 						    EPHY_COMPLETION_KEYWORDS_COL,
 						    EPHY_COMPLETION_RELEVANCE_COL,
+						    EPHY_COMPLETION_URL_COL,
 						    EPHY_COMPLETION_EXTRA_COL,
-						    EPHY_COMPLETION_FAVICON_COL,
-						    EPHY_COMPLETION_URL_COL);
+						    EPHY_COMPLETION_FAVICON_COL);
+		
+		ephy_location_entry_set_match_func (EPHY_LOCATION_ENTRY (proxy),
+							match_func,
+							proxy,
+							NULL);
 
 		add_completion_actions (action, proxy);
 
@@ -414,13 +445,13 @@ connect_proxy (GtkAction *action, GtkWidget *proxy)
 					 G_CALLBACK (get_title_cb), action, 0);
 	}
 
-	GTK_ACTION_CLASS (parent_class)->connect_proxy (action, proxy);
+	GTK_ACTION_CLASS (ephy_location_action_parent_class)->connect_proxy (action, proxy);
 }
 
 static void
 disconnect_proxy (GtkAction *action, GtkWidget *proxy)
 {
-	GTK_ACTION_CLASS (parent_class)->disconnect_proxy (action, proxy);
+	GTK_ACTION_CLASS (ephy_location_action_parent_class)->disconnect_proxy (action, proxy);
 
 	if (EPHY_IS_LOCATION_ENTRY (proxy))
 	{
@@ -526,8 +557,6 @@ ephy_location_action_class_init (EphyLocationActionClass *class)
 	GObjectClass *object_class = G_OBJECT_CLASS (class);
 	GtkActionClass *action_class = GTK_ACTION_CLASS (class);
 
-	parent_class = g_type_class_peek_parent (class);
-
 	object_class->finalize = ephy_location_action_finalize;
 	object_class->get_property = ephy_location_action_get_property;
 	object_class->set_property = ephy_location_action_set_property;
@@ -731,6 +760,9 @@ ephy_location_action_init (EphyLocationAction *action)
 		(action->priv->bookmarks);
 
 	init_actions_list (action);
+	
+	priv->history = ephy_history_get_pages (EPHY_HISTORY (
+			ephy_embed_shell_get_global_history (embed_shell)));
 
 	ephy_node_signal_connect_object (priv->smart_bmks,
 			                 EPHY_NODE_CHILD_ADDED,
@@ -763,7 +795,7 @@ ephy_location_action_finalize (GObject *object)
 	g_free (priv->lock_stock_id);
 	g_free (priv->lock_tooltip);
 
-	G_OBJECT_CLASS (parent_class)->finalize (object);
+	G_OBJECT_CLASS (ephy_location_action_parent_class)->finalize (object);
 }
 
 const char *
